# mammath

Mammath is the python library with all the functions you need to do complicated mathematics (e.g logarithms, integrals, 3D graphing, and more).

It is built upon several other modules including sys, tkinter, string, time, math, cmath, fractions, mpmath, keyboard, numpy, sympy, tabulate, re, matplotlib, and modules within them.

You can have full detail on its functions using the help(mammath) syntax in the shell after importing the module.

We hope Mammath is a useful and reliable asset.

Thank you!